@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,26 +15,32 @@
 #include <KMessageBox>
 
 #include <KConfigGroup>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QFile>
 #include <QLabel>
 #include <QPushButton>
 #include <QStandardPaths>
 #include <QVBoxLayout>
+#include <QWindow>
 
+namespace
+{
+static const char myBackupFileStructureInfoDialogGroupName[] = "BackupFileStructureInfoDialog";
+}
 BackupFileStructureInfoDialog::BackupFileStructureInfoDialog(QWidget *parent)
     : QDialog(parent)
     , mEditor(new KPIMTextEdit::PlainTextEditorWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Archive File Structure"));
     auto mainLayout = new QVBoxLayout(this);
-    QLabel *lab = new QLabel(i18n("Backup Archive Structure:"));
+    auto lab = new QLabel(i18n("Backup Archive Structure:"));
     mainLayout->addWidget(lab);
     mEditor->editor()->setWebShortcutSupport(false);
     mEditor->setReadOnly(true);
     mainLayout->addWidget(mEditor);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &BackupFileStructureInfoDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &BackupFileStructureInfoDialog::reject);
     buttonBox->button(QDialogButtonBox::Close)->setDefault(true);
@@ -60,17 +66,18 @@ void BackupFileStructureInfoDialog::loadStructure()
     mEditor->setPlainText(QString::fromLatin1(f.readAll()));
 }
 
-void BackupFileStructureInfoDialog::writeConfig()
-{
-    KConfigGroup group(KSharedConfig::openStateConfig(), "BackupFileStructureInfoDialog");
-    group.writeEntry("Size", size());
-}
-
 void BackupFileStructureInfoDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "BackupFileStructureInfoDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myBackupFileStructureInfoDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
+}
+
+void BackupFileStructureInfoDialog::writeConfig()
+{
+    KConfigGroup group(KSharedConfig::openStateConfig(), myBackupFileStructureInfoDialogGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
