@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,9 +23,15 @@
 #include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KTreeWidgetSearchLine>
+#include <KWindowConfig>
 #include <QFileDialog>
 #include <QTemporaryDir>
-#include <kwidgetsaddons_version.h>
+#include <QWindow>
+
+namespace
+{
+static const char myShowArchiveStructureDialogGroupName[] = "ShowArchiveStructureDialog";
+}
 
 ShowArchiveStructureDialog::ShowArchiveStructureDialog(const QString &filename, QWidget *parent)
     : QDialog(parent)
@@ -130,21 +136,12 @@ void ShowArchiveStructureDialog::slotExtractFile()
                                                                       QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
                 if (!dir.isEmpty()) {
                     if (QFile(dir + QLatin1Char('/') + currentFile->name()).exists()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                         if (KMessageBox::questionTwoActions(this,
-#else
-                        if (KMessageBox::questionYesNo(this,
-
-#endif
                                                             i18n("Do you want to overwrite %1?", currentFile->name()),
                                                             i18n("File Already Exist"),
                                                             KStandardGuiItem::overwrite(),
                                                             KStandardGuiItem::cancel())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                             == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-                            == KMessageBox::No) {
-#endif
                             return;
                         }
                     }
@@ -273,17 +270,18 @@ QTreeWidgetItem *ShowArchiveStructureDialog::addTopItem(const QString &name)
     return item;
 }
 
-void ShowArchiveStructureDialog::writeConfig()
-{
-    KConfigGroup group(KSharedConfig::openStateConfig(), "ShowArchiveStructureDialog");
-    group.writeEntry("Size", size());
-}
-
 void ShowArchiveStructureDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "ShowArchiveStructureDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myShowArchiveStructureDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
+}
+
+void ShowArchiveStructureDialog::writeConfig()
+{
+    KConfigGroup group(KSharedConfig::openStateConfig(), myShowArchiveStructureDialogGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
